/// <reference types="node" />
import express from "express";
import type { Request as ExpressRequest, Response as ExpressResponse } from "express";
import type { Handler, Document, Context as OpenAPIBackendContext } from "openapi-backend";
import type { SimulationStore, ExtendSimulationActionsInput, ExtendSimulationActions, ExtendSimulationSelectorsInput, ExtendSimulationSelectors } from "./store/index";
import type { ExtendSimulationSchemaInput, ExtendSimulationSchema } from "./store/schema";
import type { RecursivePartial } from "./store/types";
type SimulationHandlerFunctions = (context: OpenAPIBackendContext, request: ExpressRequest, response: ExpressResponse) => void;
export type SimulationHandlers = Record<string, SimulationHandlerFunctions>;
export type { ExtendSimulationActions, ExtendSimulationSelectors, ExtendSimulationSchema, SimulationStore, Document, };
export type { AnyState } from "starfx";
export declare function createFoundationSimulationServer<ExtendedSimulationSchema, ExtendedSimulationActions, ExtendedSimulationSelectors>({ port, openapi, extendStore, extendRouter, }: {
    port: number;
    openapi?: {
        document: Document | (Document | RecursivePartial<Document>)[];
        handlers: (simulationStore: SimulationStore<ExtendedSimulationSchema, ExtendedSimulationActions, ExtendedSimulationSelectors>) => Record<string, Handler | Record<string, Handler>>;
        apiRoot?: string;
    }[];
    extendStore?: {
        schema: ExtendSimulationSchemaInput<ExtendedSimulationSchema>;
        actions: ExtendSimulationActionsInput<ExtendedSimulationActions, ExtendedSimulationSchema>;
        selectors: ExtendSimulationSelectorsInput<ExtendedSimulationSelectors, ExtendedSimulationSchema>;
    };
    extendRouter?(router: express.Router, simulationStore: SimulationStore<ExtendedSimulationSchema, ExtendedSimulationActions, ExtendedSimulationSelectors>): void;
}): () => {
    listen: (portOverride?: number, callback?: () => void) => Promise<{
        server: import("http").Server<typeof import("http").IncomingMessage, typeof import("http").ServerResponse>;
        ensureClose: () => Promise<void>;
    }>;
};
export declare function startFoundationSimulationServer<ExtendedSimulationSchema, ExtendedSimulationActions, ExtendedSimulationSelectors>(arg: Parameters<typeof createFoundationSimulationServer<ExtendedSimulationSchema, ExtendedSimulationActions, ExtendedSimulationSelectors>>[0]): Promise<{
    server: import("http").Server<typeof import("http").IncomingMessage, typeof import("http").ServerResponse>;
    ensureClose: () => Promise<void>;
}>;
//# sourceMappingURL=index.d.ts.map