"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createSimulationStore = void 0;
const setup_1 = require("./setup");
const starfx_1 = require("starfx");
const starfx_2 = require("starfx");
function createSimulationStore({ actions: inputActions, selectors: inputSelectors, schema: inputSchema, } = {
    schema: (() => ({})),
    actions: (() => ({})),
    selectors: (() => ({})),
}) {
    const thunks = (0, starfx_2.createThunks)();
    // catch errors from task and logs them with extra info
    thunks.use(starfx_2.mdw.err);
    // where all the thunks get called in the middleware stack
    thunks.use(thunks.routes());
    let batchUpdater = thunks.create("update", function* (ctx, next) {
        yield* (0, starfx_2.updateStore)(ctx.payload);
        yield* next();
    });
    let additionalTasks = [thunks.bootup];
    let { store, schema } = (0, setup_1.setupStore)({
        logs: false,
        additionalTasks,
        inputSchema,
    });
    let inputedActions = inputActions({ thunks, store, schema });
    let actions = {
        batchUpdater,
        ...inputedActions,
    };
    let inputedSelectors = inputSelectors({ store, schema, createSelector: starfx_1.createSelector });
    return {
        store,
        schema,
        actions,
        selectors: inputedSelectors,
    };
}
exports.createSimulationStore = createSimulationStore;
//# sourceMappingURL=index.js.map