"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupStore = void 0;
const starfx_1 = require("starfx");
const schema_1 = require("./schema");
function setupStore({ logs = true, additionalTasks = [], initialState, inputSchema, }) {
    let [schema, schemaInitialState] = (0, schema_1.generateSchemaWithInputSlices)(inputSchema);
    let store = (0, starfx_1.createStore)({
        initialState: {
            ...schemaInitialState,
            ...initialState,
        },
    });
    let tsks = [...additionalTasks];
    if (logs) {
        // log all actions dispatched
        tsks.push(function* logActions() {
            while (true) {
                let action = yield* (0, starfx_1.take)("*");
                console.dir(action, { depth: 5 });
            }
        });
    }
    store.run(function* () {
        let group = yield* (0, starfx_1.parallel)(tsks);
        yield* group;
    });
    return { store, schema };
}
exports.setupStore = setupStore;
//# sourceMappingURL=setup.js.map